@@ -67,6 +67,7 @@ pub mod prelude {
     pub use super::build::PlotIteratorExt;
     pub use super::formatm;
     pub use super::plots;
+    pub use super::simple_fmt;
     pub use super::simple_theme::SimpleTheme;
     pub use super::ticks::TickFormatExt;
 }
@@ -112,6 +113,47 @@ macro_rules! plots {
     };
 }
 
+///
+/// Create plots without having to manually create the ticks
+/// for each axis.
+///
+/// ### No canvas argument.
+/// ```
+/// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
+/// let plotter=poloto::simple_fmt!(poloto::build::line("",data),"title","x","y");
+/// let mut k=String::new();
+/// plotter.render(&mut k);
+/// ```
+///
+/// ### With canvas argument.
+/// ```
+/// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
+/// let canvas=poloto::render::canvas();
+/// let plotter=poloto::simple_fmt!(canvas,poloto::build::line("",data),"title","x","y");
+/// let mut k=String::new();
+/// plotter.render(&mut k);
+/// ```
+
+///
+#[macro_export]
+macro_rules! simple_fmt {
+    ($data:expr,$title:expr,$xname:expr,$yname:expr) => {{
+        let canvas = poloto::render::canvas_builder().build();
+        let data = canvas.build_moved($data);
+        let (bx, by) = data.bounds();
+        let xt = $crate::ticks::from_default(bx);
+        let yt = $crate::ticks::from_default(by);
+        data.plot_with($crate::plot_fmt($title, $xname, $yname, xt, yt))
+    }};
+    ($canvas:expr,$data:expr,$title:expr,$xname:expr,$yname:expr) => {{
+        let data = $canvas.build($data);
+        let (bx, by) = data.bounds();
+        let xt = $crate::ticks::from_default(bx);
+        let yt = $crate::ticks::from_default(by);
+        data.plot_with($crate::plot_fmt($title, $xname, $yname, xt, yt))
+    }};
+}
+
 ///
 /// Leverage rust's display format system using [`std::cell::RefCell`] under the hood.
 ///
